@@ -20,7 +20,7 @@ def rook_test():
 
         rook.start(throw_errors=True)
         success = True
-    except:
+    except:  # lgtm[py/catch-base-exception]
         six.print_(file=sys.stderr)
         traceback.print_exc()
         six.print_(file=sys.stderr)
