@@ -9,9 +9,9 @@ class ActionRunProcessor(object):
         else:
             self.post_processor = None
 
-    def execute(self, aug_id, namespace, output):
+    def execute(self, aug_id, report_id, namespace, output):
         self.processor.process(namespace)
-        output.send_user_message(aug_id, namespace['store'])
+        output.send_user_message(aug_id, report_id, namespace['store'])
 
         if self.post_processor:
             output.flush_messages()
