@@ -21,6 +21,7 @@ from rook import config
 from rook.processor.processor_factory import ProcessorFactory
 
 from rook.exceptions import ToolException, RookAugInvalidKey, RookObjectNameMissing, RookUnknownObject, RookInvalidObjectConfiguration, RookUnsupportedLocation
+import rook.utils as utils
 
 
 class AugFactory(Factory):
@@ -75,14 +76,16 @@ class AugFactory(Factory):
         if not rate_limits:
             rate_limits = (200, 5000)
 
-        max_aug_execution_time = AugFactory.get_dict_value(configuration, 'maxAugTime', config.InstrumentationConfig.MAX_AUG_TIME)
+        max_aug_execution_time = AugFactory.get_dict_value(configuration, 'maxAugTime', config.InstrumentationConfig.MAX_AUG_TIME_MS)
+        max_aug_execution_time = utils.milliseconds_to_int_nano_seconds(max_aug_execution_time)
+        rate_limits = tuple(utils.milliseconds_to_int_nano_seconds(r) for r in rate_limits)
 
         aug = Aug(aug_id=aug_id,
-                   extractor=extractor,
-                   condition=condition,
-                   action=action,
-                   max_aug_execution_time=max_aug_execution_time,
-                   rate_limits=rate_limits)
+                  extractor=extractor,
+                  condition=condition,
+                  action=action,
+                  max_aug_execution_time_ns=max_aug_execution_time,
+                  rate_limits_ns=rate_limits)
 
         try:
             locationDict = configuration['location']
