@@ -1,4 +1,5 @@
 import json
+from rook.config import update_config
 
 class CommandHandler(object):
     def __init__(self, agent_com, aug_manager):
@@ -10,6 +11,8 @@ class CommandHandler(object):
         self._agent_com.on("RemoveAugCommand", self._handle_remove_aug)
 
     def _handle_initial_augs(self, initial_augs):
+        update_config(initial_augs.sdk_configuration)
+
         augs = [json.loads(aug_json) for aug_json in initial_augs.augs]
         self._aug_manager.initialize_augs(augs)
 
