@@ -64,7 +64,7 @@ class MessageCallback(object):
 
 
 class AgentCom(object):
-    def __init__(self, agent_id, host, port, proxy, token, labels, tags, debug):
+    def __init__(self, agent_id, host, port, proxy, token, labels, tags, debug, print_on_initial_connection):
         self.id = agent_id
 
         self._init_connect_thread()
@@ -89,6 +89,7 @@ class AgentCom(object):
         self.debug = debug
 
         self._callbacks = {}
+        self._print_on_initial_connection = print_on_initial_connection
 
         def set_ready_event(*args):
             self._ready_event.set()
@@ -199,6 +200,10 @@ class AgentCom(object):
                 connected = True
                 last_successful_connection = time.time()
 
+            if self._print_on_initial_connection:
+                # So there is no print on reconnect
+                self._print_on_initial_connection = False
+                six.print_("[Rookout] Successfully connected to controller.")
             logger.debug("WebSocket connected successfully")
             self._token_valid = True
 
