@@ -1,6 +1,6 @@
 import socket
 
-import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows
+import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows lgtm[py/unused-import]
 from rook.com_ws import poll_select
 from threading import Event
 
@@ -34,8 +34,9 @@ class SelectableEvent(object):
         return self._event.is_set()
 
     def set(self):
-        self._event.set()
-        self._writesocket.send(b'1')
+        if not self.is_set():
+            self._event.set()
+            self._writesocket.send(b'1')
 
     def wait(self, timeout=None):
         if self._event.is_set():
