@@ -54,7 +54,7 @@ class MessageCallback(object):
 
 
 class AgentCom(object):
-    def __init__(self, agent_id, host, port, proxy, token, labels, tags, debug):
+    def __init__(self, agent_id, host, port, proxy, token, labels, tags, debug, print_on_initial_connection):
         self.id = agent_id
 
         self._host = host if '://' in host else 'ws://' + host
@@ -79,6 +79,7 @@ class AgentCom(object):
         self._callbacks = {}
 
         self._thread = None
+        self._print_on_initial_connection = print_on_initial_connection
 
         def set_ready_event(*args):
             self._ready_event.set()
@@ -128,6 +129,9 @@ class AgentCom(object):
         self._queue.put(packaged_message)
         return None
 
+    def is_queue_full(self):
+        return self._queue.qsize() >= AgentComConfiguration.MAX_QUEUED_MESSAGES
+
     def on(self, message_name, callback):
         self._register_callback(message_name, MessageCallback(callback, True))
 
@@ -192,6 +196,10 @@ class AgentCom(object):
                 connected = True
                 last_successful_connection = time.time()
 
+            if self._print_on_initial_connection:
+                # So there is no print on reconnect
+                self._print_on_initial_connection = False
+                six.print_("[Rookout] Successfully connected to controller.")
             logger.debug("WebSocket connected successfully")
             self._token_valid = True
             with self.await_message('InitialAugsCommand') as got_initial_augs_event:
