@@ -28,7 +28,8 @@ if not hasattr(socket, "socketpair"):
 
         # We create a connected TCP socket. Note the trick with
         # setblocking(False) that prevents us from having to create a thread.
-        with socket.socket(family, type, proto) as lsock:
+        lsock = socket.socket(family, type, proto)
+        try:
             lsock.bind((host, 0))
             lsock.listen(min(socket.SOMAXCONN, 128))
             # On IPv6, ignore flow_info and scope_id
@@ -52,7 +53,8 @@ if not hasattr(socket, "socketpair"):
             except Exception:
                 csock.close()
                 raise
-
+        finally:
+            lsock.close()
         return (ssock, csock)
 
     socket.socketpair = socketpair
\ No newline at end of file
