@@ -1,4 +1,6 @@
 from .version import VERSION
+import six
+_TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True]
 
 
 class LoggingConfiguration(object):
@@ -36,7 +38,7 @@ class AgentComConfiguration(object):
     PING_INTERVAL = 10
     RESET_BACKOFF_TIMEOUT = 3*60.0
     FLUSH_TIMEOUT = 3
-    MAX_QUEUED_MESSAGES = 500
+    MAX_QUEUED_MESSAGES = 100
 
 
 class OutputWsConfiguration(object):
@@ -46,10 +48,14 @@ class OutputWsConfiguration(object):
     BUCKET_REFRESH_RATE = 10
 
 
+class RateLimiter(object):
+    MIN_RATE_LIMIT_VALUE_NS = 1000
+
+
 class InstrumentationConfig(object):
     ENGINE = "auto"
     MIN_TIME_BETWEEN_HITS_MS = 100
-    MAX_AUG_TIME = 400
+    MAX_AUG_TIME_MS = 400
 
 
 class ImportServiceConfig(object):
@@ -69,3 +75,21 @@ class GitConfig(object):
 
 class ShutdownConfig(object):
     IS_SHUTTING_DOWN = False
+
+
+class DumpConfig(object):
+    STRING_CACHE_USERMESSAGE = False
+
+
+def update_config(new_config):
+    try:
+        for key, val in six.iteritems(new_config):
+            if key == 'PYTHON_StringCache_UserMessage':
+                DumpConfig.STRING_CACHE_USERMESSAGE = val in _TRUE_VALUES
+                continue
+    except:
+        try:
+            from rook.logger import logger
+            logger.exception("Failed to update configuration: " + str(new_config))
+        except:  # lgtm[py/catch-base-exception]
+            pass
