@@ -23,11 +23,11 @@ class FileUtils(object):
             logger.exception("Error while reading file")
             return None
 
-    def get_file_contents(self, aug, module, filepath):
+    def get_file_contents(self, location, module, filepath):
         if not filepath:
             if module.__file__.endswith('.pyc'):
-                if aug:
-                    aug.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
+                if location:
+                    location.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
                 return None
             raise RookHashFailedException(module.__name__)
 
@@ -42,8 +42,8 @@ class FileUtils(object):
                 string = module.__loader__.get_data(relative_path)
             else:
                 if not os.path.isfile(filepath):
-                    if aug:
-                        aug.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
+                    if location:
+                        location.send_warning(Error(exc=RookSourceFileNotFound(module.__file__)))
                     return None
                 raise RookHashCalculationFailed(filepath, module.__name__, exc)
 
