@@ -1,7 +1,7 @@
 // Ensure that Python.h is included before any other header.
 #include "common.h"
 
-#ifdef BUILDING_FOR_CPYTHON
+#ifndef PYPY_VERSION
 namespace native_extensions {
 
 PyObject* CallImportHookRemovingFrames(PyObject* self, PyObject* args, PyObject* kwargs);
