@@ -49,6 +49,17 @@ if six.PY2:
 
 
 class NamespaceSerializer(object):
+    def __init__(self, use_string_cache=False):
+        self.use_string_cache = use_string_cache
+        self.string_cache = {}
+
+        if use_string_cache:
+            # Lock the 0 index since some variant will have no originalType (container for example)
+            self.string_cache[""] = 0
+
+    def get_string_cache(self):
+        return self.string_cache
+
     def dump(self, namespace, variant, log_errors=True):
         try:
             if isinstance(namespace, ContainerNamespace):
@@ -218,7 +229,11 @@ class NamespaceSerializer(object):
         return object_width
 
     def _dump_base_object(self, obj, variant, current_depth, config, log_errors):
-        variant.original_type = str(type(obj))
+        original_type = str(type(obj))
+        if not self.use_string_cache:
+            variant.original_type = original_type
+        else:
+            variant.original_type_index_in_cache = self._get_string_index_in_cache(original_type)
 
         object_width = self._get_object_width(obj)
         object_weight = current_depth + (2 if object_width >= config.max_width else 1)
@@ -313,7 +328,10 @@ class NamespaceSerializer(object):
                 obj = obj[:max_string]
 
             string = self.normalize_string(obj)
-            variant.string_value.value = string
+            if not self.use_string_cache:
+                variant.string_value.value = string # This is legacy code.
+            else:
+                variant.string_value.value_index_in_cache = self._get_string_index_in_cache(string)
 
         elif isinstance(obj, self.BINARY_TYPES) or original_type == 'binary_type':
             variant.variant_type = variant.VARIANT_BINARY
@@ -460,7 +478,10 @@ class NamespaceSerializer(object):
         variant.variant_type = variant.VARIANT_MAX_DEPTH
 
     def _dump_traceback_namespace(self, namespace, variant, log_errors):
-        namespace.dump(variant)
+        if not self.use_string_cache:
+            namespace.dump(variant)
+        else:
+            namespace.dump(variant, self._get_string_index_in_cache)
 
     def dump_code_namespace(self, namespace, variant, log_errors):
         self._dump_dumped_object_namespace(namespace, variant, log_errors)
@@ -605,6 +626,14 @@ class NamespaceSerializer(object):
                                    variant.original_type,
                                    self._load_attributes(variant))
 
+    def _get_string_index_in_cache(self, str):
+        if str in self.string_cache:
+            return self.string_cache[str]
+
+        current_size = len(self.string_cache)
+        self.string_cache[str] = current_size
+        return current_size
+
     @staticmethod
     def normalize_string(obj):
         if six.PY2:
