@@ -105,3 +105,9 @@ class ListNamespace(CollectionNamespace, list):
     def __hash__(self):
         return hash(tuple(k for k in self))
 
+    def __eq__(self, other):
+        if type(self) != type(other):
+            return False
+
+        return tuple(k for k in self).__eq__(tuple(k for k in other))
+
