@@ -2,9 +2,8 @@ import datetime
 
 from .dumped_object_namespace import DumpedObjectNamespace
 
-from .python_object_namespace import PythonObjectNamespace
-
 
+# TODO - remove this class
 class DumpedPrimitiveNamespace(DumpedObjectNamespace):
 
     def __init__(self, obj, type, common_type, attributes={}, methods=()):
@@ -18,6 +17,3 @@ class DumpedPrimitiveNamespace(DumpedObjectNamespace):
             return str(self.obj)
         else:
             return self.obj
-
-    def __hash__(self):
-        return hash(self.obj)
