@@ -28,8 +28,8 @@ class TracebackNamespace(Namespace):
 
         return current_frame
 
-    def dump(self, variant, getStringIndexInCache=None):
-        variant.variant_type = variant_pb2.Variant.Type.VARIANT_TRACEBACK
+    def dump(self, variant, get_string_index_in_cache=None):
+        variant.variant_type = variant_pb2.Variant.VARIANT_TRACEBACK
 
         current_frame = self._frame
 
@@ -37,14 +37,14 @@ class TracebackNamespace(Namespace):
             frame = variant_pb2.Variant.CodeObject()
 
             frame.lineno = current_frame.line().obj if current_frame.line().obj is not None else 0
-            if getStringIndexInCache is None:
+            if get_string_index_in_cache is None:
                 frame.filename = current_frame.filename().obj if current_frame.filename().obj is not None else "unavailable"
                 frame.name = current_frame.function().obj if current_frame.function().obj is not None else "unavailable"
                 frame.module = current_frame.module().obj if current_frame.module().obj is not None else "unavailable"
             else:
-                frame.filename_index_in_cache = getStringIndexInCache(current_frame.filename().obj if current_frame.filename().obj is not None else "unavailable")
-                frame.name_index_in_cache = getStringIndexInCache(current_frame.function().obj if current_frame.function().obj is not None else "unavailable")
-                frame.module_index_in_cache = getStringIndexInCache(current_frame.module().obj if current_frame.module().obj is not None else "unavailable")
+                frame.filename_index_in_cache = get_string_index_in_cache(current_frame.filename().obj if current_frame.filename().obj is not None else "unavailable")
+                frame.name_index_in_cache = get_string_index_in_cache(current_frame.function().obj if current_frame.function().obj is not None else "unavailable")
+                frame.module_index_in_cache = get_string_index_in_cache(current_frame.module().obj if current_frame.module().obj is not None else "unavailable")
 
             variant.traceback.locations.append(frame)
 
