@@ -21,7 +21,9 @@ class Processor(object):
                 message = "Error in operation"
                 logger.exception(message)
                 UserWarnings.send_warning(Error(exc=exc, message=message))
-                return
+                return None
 
             if result is not None:
                 return result
+
+        return None
