@@ -28,7 +28,7 @@ def worker_main(*args, **kwargs):
                 # this is here to deal with the delay of having the periodic thread call evaluate_module_list -
                 # it could miss a module being imported.
                 import_service.evaluate_module_list()
-            except:
+            except:  # lgtm[py/catch-base-exception]
                 logger.exception("Silenced exception during module list evaluation")
             return obj
 
@@ -37,7 +37,7 @@ def worker_main(*args, **kwargs):
         if ImportServiceConfig.USE_IMPORT_HOOK is False:  # only do this if we're not using the import hook
             pyspark.serializers.pickle.loads = functools.partial(pickle_load_hook, pyspark.serializers.pickle.loads)
             pyspark.serializers.pickle.load = functools.partial(pickle_load_hook, pyspark.serializers.pickle.load)
-    except:
+    except:  # lgtm[py/catch-base-exception]
         six.print_("Starting Rook in worker_main failed", file=sys.stderr)
 
     result = original_worker_main(*args, **kwargs)
