@@ -125,11 +125,16 @@ static PythonOpcodeType GetOpcodeType(uint8 opcode) {
     case FOR_ITER:
     case JUMP_FORWARD:
 #if PY_VERSION_HEX < 0x03080000
+    // Removed in Python 3.8.
     case SETUP_LOOP:
     case SETUP_EXCEPT:
 #endif
     case SETUP_FINALLY:
     case SETUP_WITH:
+#if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
+    // Added in Python 3.8 and removed in 3.9
+    case CALL_FINALLY:
+#endif
       return BRANCH_DELTA_OPCODE;
 
     case JUMP_IF_FALSE_OR_POP:
@@ -138,6 +143,7 @@ static PythonOpcodeType GetOpcodeType(uint8 opcode) {
     case POP_JUMP_IF_FALSE:
     case POP_JUMP_IF_TRUE:
 #if PY_VERSION_HEX < 0x03080000
+    // Removed in Python 3.8.
     case CONTINUE_LOOP:
 #endif
       return BRANCH_ABSOLUTE_OPCODE;
