@@ -278,7 +278,7 @@ class _VisitRecorder(object):
     # id may potentially invoke end user code, so we protect it with a try/except
     try:
       obj_id = id(obj)
-    except:
+    except Exception:
       return False
 
     if obj_id in self._visit_recorder_objects:
