@@ -115,7 +115,7 @@ class LoggingLocationService(object):
             # Don't have unit tests
             except AssertionError:
                 raise
-            except:
+            except:  # lgtm[py/catch-base-exception]
                 pass
 
         # This requires a bit of explanation why we're doing this.  Due to how
@@ -150,8 +150,6 @@ class LoggingLocationService(object):
         new_func = ns['factory'](func, _callback)
         new_func.__doc__ = func.__doc__
 
-        assert code.co_firstlineno == code.co_firstlineno
-
         # In theory this should already be set correctly, but in some cases
         # it is not.  So override it.
         new_func.__module__ = func.__module__
